@@ -2,7 +2,6 @@
 
 from .__main__ import run
 from .commands import (
-    handle_device_feature_request,
     handle_device_info_request,
     handle_get_controller_serial_request,
     handle_get_energy_request,
@@ -12,19 +11,21 @@ from .commands import (
     handle_set_dhw_temp_request,
     handle_set_mode_request,
     handle_set_tou_enabled_request,
-    handle_status_raw_request,
     handle_status_request,
     handle_update_reservations_request,
 )
 from .monitoring import handle_monitoring
-from .output_formatters import format_json_output, print_json, write_status_to_csv
+from .output_formatters import (
+    format_json_output,
+    print_json,
+    write_status_to_csv,
+)
 from .token_storage import load_tokens, save_tokens
 
 __all__ = [
     # Main entry point
     "run",
     # Command handlers
-    "handle_device_feature_request",
     "handle_device_info_request",
     "handle_get_controller_serial_request",
     "handle_get_energy_request",
@@ -35,7 +36,6 @@ __all__ = [
     "handle_set_dhw_temp_request",
     "handle_set_mode_request",
     "handle_set_tou_enabled_request",
-    "handle_status_raw_request",
     "handle_status_request",
     "handle_update_reservations_request",
     # Output formatters
