@@ -7,7 +7,7 @@ These models are based on the MQTT message formats and API responses.
 """
 
 import logging
-from typing import Annotated, Any
+from typing import Annotated, Any, Self
 
 from pydantic import BaseModel, BeforeValidator, ConfigDict, Field
 from pydantic.alias_generators import to_camel
@@ -15,14 +15,20 @@ from pydantic.alias_generators import to_camel
 from .enums import (
     CurrentOperationMode,
     DeviceType,
+    DHWControlTypeFlag,
     DhwOperationSetting,
     DREvent,
     ErrorCode,
     HeatSource,
+    RecirculationMode,
     TemperatureType,
     TempFormulaType,
     UnitType,
 )
+from .field_factory import (
+    signal_strength_field,
+    temperature_field,
+)
 
 _logger = logging.getLogger(__name__)
 
@@ -33,53 +39,24 @@ _logger = logging.getLogger(__name__)
 
 
 def _device_bool_validator(v: Any) -> bool:
-    """Convert device boolean (2=True, 0/1=False)."""
-    return bool(v == 2)
-
-
-def _capability_flag_validator(v: Any) -> bool:
-    """Convert capability flag (2=True/supported, 1=False/not supported).
-
-    Uses same pattern as OnOffFlag: 1=OFF/not supported, 2=ON/supported.
-    """
+    """Convert device boolean flag (2=True, 1=False)."""
     return bool(v == 2)
 
 
 def _div_10_validator(v: Any) -> float:
     """Divide by 10."""
-    if isinstance(v, (int, float)):
-        return float(v) / 10.0
-    return float(v)
+    return float(v) / 10.0 if isinstance(v, (int, float)) else float(v)
 
 
 def _half_celsius_to_fahrenheit(v: Any) -> float:
     """Convert half-degrees Celsius to Fahrenheit."""
     if isinstance(v, (int, float)):
-        celsius = float(v) / 2.0
-        return (celsius * 9 / 5) + 32
+        return (float(v) / 2.0 * 9 / 5) + 32
     return float(v)
 
 
 def fahrenheit_to_half_celsius(fahrenheit: float) -> int:
-    """Convert Fahrenheit to half-degrees Celsius (for device commands).
-
-    This is the inverse of the HalfCelsiusToF conversion used for reading.
-    Use this when sending temperature values to the device (e.g., reservations).
-
-    Args:
-        fahrenheit: Temperature in Fahrenheit (e.g., 140.0)
-
-    Returns:
-        Integer value in half-degrees Celsius for device param field
-
-    Examples:
-        >>> fahrenheit_to_half_celsius(140.0)
-        120
-        >>> fahrenheit_to_half_celsius(120.0)
-        98
-        >>> fahrenheit_to_half_celsius(95.0)
-        70
-    """
+    """Convert Fahrenheit to half-degrees Celsius (for device commands)."""
     celsius = (fahrenheit - 32) * 5 / 9
     return round(celsius * 2)
 
@@ -87,30 +64,23 @@ def fahrenheit_to_half_celsius(fahrenheit: float) -> int:
 def _deci_celsius_to_fahrenheit(v: Any) -> float:
     """Convert decicelsius (tenths of Celsius) to Fahrenheit."""
     if isinstance(v, (int, float)):
-        celsius = float(v) / 10.0
-        return (celsius * 9 / 5) + 32
+        return (float(v) / 10.0 * 9 / 5) + 32
     return float(v)
 
 
 def _tou_status_validator(v: Any) -> bool:
-    """Convert TOU status (0=False/disabled, 1=True/enabled)."""
+    """Convert TOU status (0=False, 1=True)."""
     return bool(v == 1)
 
 
 def _tou_override_validator(v: Any) -> bool:
-    """Convert TOU override status (1=True/override active, 2=False/normal).
-
-    Note: This field uses OnOffFlag pattern (1=OFF, 2=ON) but represents
-    whether TOU schedule operation is enabled, not whether override is active.
-    So: 2 (ON) = TOU operating normally = override NOT active = False
-        1 (OFF) = TOU not operating = override IS active = True
-    """
+    """Convert TOU override status (1=True, 2=False)."""
     return bool(v == 1)
 
 
 # Reusable Annotated types for conversions
 DeviceBool = Annotated[bool, BeforeValidator(_device_bool_validator)]
-CapabilityFlag = Annotated[bool, BeforeValidator(_capability_flag_validator)]
+CapabilityFlag = Annotated[bool, BeforeValidator(_device_bool_validator)]
 Div10 = Annotated[float, BeforeValidator(_div_10_validator)]
 HalfCelsiusToF = Annotated[float, BeforeValidator(_half_celsius_to_fahrenheit)]
 DeciCelsiusToF = Annotated[float, BeforeValidator(_deci_celsius_to_fahrenheit)]
@@ -144,49 +114,42 @@ class NavienBaseModel(BaseModel):
 
     @staticmethod
     def _convert_enums_to_names(
-        data: Any, visited: set[int | None] = None
+        data: Any, visited: set[int] | None = None
     ) -> Any:
         """Recursively convert Enum values to their names.
 
         Args:
-            data: Data to convert
-            visited: Set of visited object ids to detect cycles
-
-        Returns:
-            Data with enums converted to their names
+            data: The data structure to convert.
+            visited: Set of object IDs already visited to prevent infinite
+                     recursion. None indicates uninitialized/first call.
         """
         from enum import Enum
 
-        if visited is None:
-            visited = set()
-
         if isinstance(data, Enum):
             return data.name
-        elif isinstance(data, dict):
-            # Check for circular reference
-            data_id = id(data)
-            if data_id in visited:
-                return data
-            visited.add(data_id)
-            result: dict[Any, Any] = {
-                key: NavienBaseModel._convert_enums_to_names(value, visited)
-                for key, value in data.items()
+        if not isinstance(data, (dict, list, tuple)):
+            return data
+
+        visited = visited or set()
+        if id(data) in visited:
+            return data
+        visited.add(id(data))
+
+        if isinstance(data, dict):
+            res: dict[Any, Any] | list[Any] | tuple[Any, ...] = {
+                k: NavienBaseModel._convert_enums_to_names(v, visited)
+                for k, v in data.items()
             }
-            visited.discard(data_id)
-            return result
-        elif isinstance(data, (list, tuple)):
-            # Check for circular reference
-            data_id = id(data)
-            if data_id in visited:
-                return data
-            visited.add(data_id)
-            converted = [
-                NavienBaseModel._convert_enums_to_names(item, visited)
-                for item in data
-            ]
-            visited.discard(data_id)
-            return type(data)(converted)
-        return data
+        else:
+            res = type(data)(
+                [
+                    NavienBaseModel._convert_enums_to_names(i, visited)
+                    for i in data
+                ]
+            )
+
+        visited.discard(id(data))
+        return res
 
 
 class DeviceInfo(NavienBaseModel):
@@ -218,6 +181,10 @@ class Device(NavienBaseModel):
     device_info: DeviceInfo
     location: Location
 
+    def with_info(self, info: DeviceInfo) -> Self:
+        """Return a new Device instance with updated DeviceInfo."""
+        return self.model_copy(update={"device_info": info})
+
 
 class FirmwareInfo(NavienBaseModel):
     """Firmware information for a device."""
@@ -259,7 +226,7 @@ class TOUInfo(NavienBaseModel):
         *,
         strict: bool | None = None,
         from_attributes: bool | None = None,
-        context: dict[str, Any | None] = None,
+        context: dict[str, Any | None] | None = None,
         **kwargs: Any,
     ) -> "TOUInfo":
         # Handle nested structure where fields are in 'touInfo'
@@ -289,12 +256,8 @@ class DeviceStatus(NavienBaseModel):
     command: int = Field(
         description="The command that triggered this status update"
     )
-    outside_temperature: float = Field(
-        description="The outdoor/ambient temperature measured by the heat pump",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    outside_temperature: float = temperature_field(
+        "The outdoor/ambient temperature measured by the heat pump"
     )
     special_function_status: int = Field(
         description=(
@@ -319,15 +282,9 @@ class DeviceStatus(NavienBaseModel):
     )
     fault_status1: int = Field(description="Fault status register 1")
     fault_status2: int = Field(description="Fault status register 2")
-    wifi_rssi: int = Field(
-        description=(
-            "WiFi signal strength in dBm. "
-            "Typical values: -30 (excellent) to -90 (poor)"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "dBm",
-            "device_class": "signal_strength",
-        },
+    wifi_rssi: int = signal_strength_field(
+        "WiFi signal strength in dBm. "
+        "Typical values: -30 (excellent) to -90 (poor)"
     )
     dhw_charge_per: float = Field(
         description=(
@@ -454,7 +411,7 @@ class DeviceStatus(NavienBaseModel):
             "device_class": "energy",
         },
     )
-    recirc_operation_mode: int = Field(
+    recirc_operation_mode: RecirculationMode = Field(
         description="Recirculation operation mode"
     )
     recirc_pump_operation_status: int = Field(
@@ -504,6 +461,13 @@ class DeviceStatus(NavienBaseModel):
             "Sustained DHW usage status - indicates prolonged hot water usage"
         )
     )
+    dhw_operation_busy: DeviceBool = Field(
+        default=False,
+        description=(
+            "DHW operation busy status - "
+            "indicates if the device is currently heating water to meet demand"
+        ),
+    )
     program_reservation_use: DeviceBool = Field(
         description=(
             "Whether a program reservation (scheduled operation) is in use"
@@ -601,144 +565,64 @@ class DeviceStatus(NavienBaseModel):
     )
 
     # Temperature fields - encoded in half-degrees Celsius
-    dhw_temperature: HalfCelsiusToF = Field(
-        description="Current Domestic Hot Water (DHW) outlet temperature",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_temperature: HalfCelsiusToF = temperature_field(
+        "Current Domestic Hot Water (DHW) outlet temperature"
     )
-    dhw_temperature_setting: HalfCelsiusToF = Field(
-        description=(
-            "User-configured target DHW temperature. "
-            "Range: 95°F (35°C) to 150°F (65.5°C). Default: 120°F (49°C)"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_temperature_setting: HalfCelsiusToF = temperature_field(
+        "User-configured target DHW temperature. "
+        "Range: 95°F (35°C) to 150°F (65.5°C). Default: 120°F (49°C)"
     )
-    dhw_target_temperature_setting: HalfCelsiusToF = Field(
-        description=(
-            "Duplicate of dhw_temperature_setting for legacy API compatibility"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_target_temperature_setting: HalfCelsiusToF = temperature_field(
+        "Duplicate of dhw_temperature_setting for legacy API compatibility"
     )
-    freeze_protection_temperature: HalfCelsiusToF = Field(
-        description=(
-            "Freeze protection temperature setpoint. "
-            "Range: 43-50°F (6-10°C), Default: 43°F"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    freeze_protection_temperature: HalfCelsiusToF = temperature_field(
+        "Freeze protection temperature setpoint. "
+        "Range: 43-50°F (6-10°C), Default: 43°F"
     )
-    dhw_temperature2: HalfCelsiusToF = Field(
-        description="Second DHW temperature reading",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_temperature2: HalfCelsiusToF = temperature_field(
+        "Second DHW temperature reading"
     )
-    hp_upper_on_temp_setting: HalfCelsiusToF = Field(
-        description="Heat pump upper on temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    hp_upper_on_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heat pump upper on temperature setting"
     )
-    hp_upper_off_temp_setting: HalfCelsiusToF = Field(
-        description="Heat pump upper off temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    hp_upper_off_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heat pump upper off temperature setting"
     )
-    hp_lower_on_temp_setting: HalfCelsiusToF = Field(
-        description="Heat pump lower on temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    hp_lower_on_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heat pump lower on temperature setting"
     )
-    hp_lower_off_temp_setting: HalfCelsiusToF = Field(
-        description="Heat pump lower off temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    hp_lower_off_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heat pump lower off temperature setting"
     )
-    he_upper_on_temp_setting: HalfCelsiusToF = Field(
-        description="Heater element upper on temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    he_upper_on_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heater element upper on temperature setting"
     )
-    he_upper_off_temp_setting: HalfCelsiusToF = Field(
-        description="Heater element upper off temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    he_upper_off_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heater element upper off temperature setting"
     )
-    he_lower_on_temp_setting: HalfCelsiusToF = Field(
-        description="Heater element lower on temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    he_lower_on_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heater element lower on temperature setting"
     )
-    he_lower_off_temp_setting: HalfCelsiusToF = Field(
-        description="Heater element lower off temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    he_lower_off_temp_setting: HalfCelsiusToF = temperature_field(
+        "Heater element lower off temperature setting"
     )
-    heat_min_op_temperature: HalfCelsiusToF = Field(
-        description=(
-            "Minimum heat pump operation temperature. "
-            "Lowest tank setpoint allowed (95-113°F, default 95°F)"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    heat_min_op_temperature: HalfCelsiusToF = temperature_field(
+        "Minimum heat pump operation temperature. "
+        "Lowest tank setpoint allowed (95-113°F, default 95°F)"
     )
-    recirc_temp_setting: HalfCelsiusToF = Field(
-        description="Recirculation temperature setting",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    recirc_temp_setting: HalfCelsiusToF = temperature_field(
+        "Recirculation temperature setting"
     )
-    recirc_temperature: HalfCelsiusToF = Field(
-        description="Recirculation temperature",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    recirc_temperature: HalfCelsiusToF = temperature_field(
+        "Recirculation temperature"
     )
-    recirc_faucet_temperature: HalfCelsiusToF = Field(
-        description="Recirculation faucet temperature",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    recirc_faucet_temperature: HalfCelsiusToF = temperature_field(
+        "Recirculation faucet temperature"
     )
 
     # Fields with scale division (raw / 10.0)
-    current_inlet_temperature: HalfCelsiusToF = Field(
-        description="Cold water inlet temperature",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    current_inlet_temperature: HalfCelsiusToF = temperature_field(
+        "Cold water inlet temperature"
     )
     current_dhw_flow_rate: Div10 = Field(
         description="Current DHW flow rate in Gallons Per Minute",
@@ -807,78 +691,34 @@ class DeviceStatus(NavienBaseModel):
     )
 
     # Temperature fields with decicelsius to Fahrenheit conversion
-    tank_upper_temperature: DeciCelsiusToF = Field(
-        description="Temperature of the upper part of the tank",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    tank_upper_temperature: DeciCelsiusToF = temperature_field(
+        "Temperature of the upper part of the tank"
     )
-    tank_lower_temperature: DeciCelsiusToF = Field(
-        description="Temperature of the lower part of the tank",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    tank_lower_temperature: DeciCelsiusToF = temperature_field(
+        "Temperature of the lower part of the tank"
     )
-    discharge_temperature: DeciCelsiusToF = Field(
-        description=(
-            "Compressor discharge temperature - "
-            "temperature of refrigerant leaving the compressor"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    discharge_temperature: DeciCelsiusToF = temperature_field(
+        "Compressor discharge temperature - "
+        "temperature of refrigerant leaving the compressor"
     )
-    suction_temperature: DeciCelsiusToF = Field(
-        description=(
-            "Compressor suction temperature - "
-            "temperature of refrigerant entering the compressor"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    suction_temperature: DeciCelsiusToF = temperature_field(
+        "Compressor suction temperature - "
+        "temperature of refrigerant entering the compressor"
     )
-    evaporator_temperature: DeciCelsiusToF = Field(
-        description=(
-            "Evaporator temperature - "
-            "temperature where heat is absorbed from ambient air"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    evaporator_temperature: DeciCelsiusToF = temperature_field(
+        "Evaporator temperature - "
+        "temperature where heat is absorbed from ambient air"
     )
-    ambient_temperature: DeciCelsiusToF = Field(
-        description=(
-            "Ambient air temperature measured at the heat pump air intake"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    ambient_temperature: DeciCelsiusToF = temperature_field(
+        "Ambient air temperature measured at the heat pump air intake"
     )
-    target_super_heat: DeciCelsiusToF = Field(
-        description=(
-            "Target superheat value - desired temperature difference "
-            "ensuring complete refrigerant vaporization"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    target_super_heat: DeciCelsiusToF = temperature_field(
+        "Target superheat value - desired temperature difference "
+        "ensuring complete refrigerant vaporization"
     )
-    current_super_heat: DeciCelsiusToF = Field(
-        description=(
-            "Current superheat value - actual temperature difference "
-            "between suction and evaporator temperatures"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    current_super_heat: DeciCelsiusToF = temperature_field(
+        "Current superheat value - actual temperature difference "
+        "between suction and evaporator temperatures"
     )
 
     # Enum fields
@@ -894,21 +734,12 @@ class DeviceStatus(NavienBaseModel):
         default=TemperatureType.FAHRENHEIT,
         description="Type of temperature unit",
     )
-    freeze_protection_temp_min: HalfCelsiusToF = Field(
+    freeze_protection_temp_min: HalfCelsiusToF = temperature_field(
+        "Active freeze protection lower limit. Default: 43°F (6°C)",
         default=43.0,
-        description="Active freeze protection lower limit. Default: 43°F (6°C)",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
     )
-    freeze_protection_temp_max: HalfCelsiusToF = Field(
-        default=65.0,
-        description="Active freeze protection upper limit. Default: 65°F",
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    freeze_protection_temp_max: HalfCelsiusToF = temperature_field(
+        "Active freeze protection upper limit. Default: 65°F", default=65.0
     )
 
     @classmethod
@@ -975,6 +806,18 @@ class DeviceFeature(NavienBaseModel):
             "for communication protocol version"
         )
     )
+    recirc_sw_version: int = Field(
+        description=(
+            "Recirculation module firmware version - "
+            "controls recirculation pump operation and temperature loop"
+        )
+    )
+    recirc_model_type_code: int = Field(
+        description=(
+            "Recirculation module model identifier - "
+            "specifies installed recirculation system variant"
+        )
+    )
     controller_serial_number: str = Field(
         description=(
             "Unique serial number of the main controller board "
@@ -982,163 +825,182 @@ class DeviceFeature(NavienBaseModel):
         )
     )
     power_use: CapabilityFlag = Field(
-        description=("Power control capability (2=supported, 1=not supported)")
+        default=False,
+        description=("Power control capability (2=supported, 1=not supported)"),
     )
     holiday_use: CapabilityFlag = Field(
+        default=False,
         description=(
             "Vacation mode support (2=supported, 1=not supported) - "
             "energy-saving mode for 0-99 days"
-        )
+        ),
     )
     program_reservation_use: CapabilityFlag = Field(
+        default=False,
         description=(
             "Scheduled operation support (2=supported, 1=not supported) - "
             "programmable heating schedules"
-        )
+        ),
     )
     dhw_use: CapabilityFlag = Field(
+        default=False,
         description=(
             "Domestic hot water functionality (2=supported, 1=not supported) - "
             "primary function of water heater"
-        )
+        ),
     )
-    dhw_temperature_setting_use: CapabilityFlag = Field(
+    dhw_temperature_setting_use: DHWControlTypeFlag = Field(
         description=(
-            "Temperature adjustment capability "
-            "(2=supported, 1=not supported) - "
-            "user can modify target temperature"
+            "DHW temperature control precision setting: "
+            "granularity of temperature adjustments available for DHW control"
         )
     )
     smart_diagnostic_use: CapabilityFlag = Field(
+        default=False,
         description=(
             "Self-diagnostic capability (2=supported, 1=not supported) - "
             "10-minute startup diagnostic, error code system"
-        )
+        ),
     )
     wifi_rssi_use: CapabilityFlag = Field(
+        default=False,
         description=(
             "WiFi signal monitoring (2=supported, 1=not supported) - "
             "reports signal strength in dBm"
-        )
+        ),
     )
     temp_formula_type: TempFormulaType = Field(
+        default=TempFormulaType.ASYMMETRIC,
         description=(
             "Temperature calculation method identifier "
             "for internal sensor calibration"
-        )
+        ),
     )
     energy_usage_use: CapabilityFlag = Field(
-        description=(
-            "Energy monitoring support (1=available) - tracks kWh consumption"
-        )
+        default=False,
+        description=("Energy monitoring support (2=supp, 1=not) - tracks kWh"),
     )
     freeze_protection_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Freeze protection capability (1=available) - "
+            "Freeze protection capability (2=supported, 1=not supported) - "
             "automatic heating when tank drops below threshold"
-        )
+        ),
     )
-    mixing_value_use: CapabilityFlag = Field(
-        description=(
-            "Thermostatic mixing valve support (1=available) - "
-            "for temperature limiting at point of use"
-        )
+    mixing_valve_use: CapabilityFlag = Field(
+        alias="mixingValveUse",
+        default=False,
+        description=("Thermostatic mixing valve support (2=supp, 1=not)"),
     )
     dr_setting_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Demand Response support (1=available) - "
+            "Demand Response support (2=supported, 1=not supported) - "
             "CTA-2045 compliance for utility load management"
-        )
+        ),
     )
     anti_legionella_setting_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Anti-Legionella function (1=available) - "
+            "Anti-Legionella function (2=supported, 1=not supported) - "
             "periodic heating to 140°F (60°C) to prevent bacteria"
-        )
+        ),
     )
     hpwh_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Heat Pump Water Heater mode (1=supported) - "
+            "Heat Pump Water Heater mode (2=supported, 1=not supported) - "
             "primary efficient heating using refrigeration cycle"
-        )
+        ),
     )
     dhw_refill_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Tank refill detection (1=supported) - "
+            "Tank refill detection (2=supported, 1=not supported) - "
             "monitors for dry fire conditions during refill"
-        )
+        ),
     )
     eco_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "ECO safety switch capability (1=available) - "
+            "ECO safety switch capability (2=supported, 1=not supported) - "
             "Energy Cut Off high-temperature limit protection"
-        )
+        ),
     )
     electric_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Electric-only mode (1=supported) - "
+            "Electric-only mode (2=supported, 1=not supported) - "
             "heating element only for maximum recovery speed"
-        )
+        ),
     )
     heatpump_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Heat pump only mode (1=supported) - "
+            "Heat pump only mode (2=supported, 1=not supported) - "
             "most efficient operation using only refrigeration cycle"
-        )
+        ),
     )
     energy_saver_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "Energy Saver mode (1=supported) - "
+            "Energy Saver mode (2=supported, 1=not supported) - "
             "hybrid efficiency mode balancing speed and efficiency (default)"
-        )
+        ),
     )
     high_demand_use: CapabilityFlag = Field(
+        default=False,
         description=(
-            "High Demand mode (1=supported) - "
+            "High Demand mode (2=supported, 1=not supported) - "
             "hybrid boost mode prioritizing fast recovery"
-        )
+        ),
+    )
+    recirculation_use: CapabilityFlag = Field(
+        default=False,
+        description=(
+            "Recirculation pump support (2=supported, 1=not supported) - "
+            "instant hot water delivery via dedicated loop"
+        ),
+    )
+    recirc_reservation_use: CapabilityFlag = Field(
+        default=False,
+        description=(
+            "Recirculation schedule support (2=supported, 1=not supported) - "
+            "programmable recirculation on specified schedule"
+        ),
+    )
+    title24_use: CapabilityFlag = Field(
+        default=False,
+        description=(
+            "Title 24 compliance (2=supported, 1=not supported) - "
+            "California energy code compliance for recirculation systems"
+        ),
     )
 
     # Temperature limit fields with half-degree Celsius scaling
-    dhw_temperature_min: HalfCelsiusToF = Field(
-        description=(
-            "Minimum DHW temperature setting: 95°F (35°C) - "
-            "safety and efficiency lower limit"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_temperature_min: HalfCelsiusToF = temperature_field(
+        "Minimum DHW temperature setting: 95°F (35°C) - "
+        "safety and efficiency lower limit"
     )
-    dhw_temperature_max: HalfCelsiusToF = Field(
-        description=(
-            "Maximum DHW temperature setting: 150°F (65.5°C) - "
-            "scald protection upper limit"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    dhw_temperature_max: HalfCelsiusToF = temperature_field(
+        "Maximum DHW temperature setting: 150°F (65.5°C) - "
+        "scald protection upper limit"
     )
-    freeze_protection_temp_min: HalfCelsiusToF = Field(
-        description=(
-            "Minimum freeze protection threshold: 43°F (6°C) - "
-            "factory default activation temperature"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    freeze_protection_temp_min: HalfCelsiusToF = temperature_field(
+        "Minimum freeze protection threshold: 43°F (6°C) - "
+        "factory default activation temperature"
     )
-    freeze_protection_temp_max: HalfCelsiusToF = Field(
-        description=(
-            "Maximum freeze protection threshold: 65°F - "
-            "user-adjustable upper limit"
-        ),
-        json_schema_extra={
-            "unit_of_measurement": "°F",
-            "device_class": "temperature",
-        },
+    freeze_protection_temp_max: HalfCelsiusToF = temperature_field(
+        "Maximum freeze protection threshold: 65°F - "
+        "user-adjustable upper limit"
+    )
+    recirc_temperature_min: HalfCelsiusToF = temperature_field(
+        "Minimum recirculation temperature setting - "
+        "lower limit for recirculation loop temperature control"
+    )
+    recirc_temperature_max: HalfCelsiusToF = temperature_field(
+        "Maximum recirculation temperature setting - "
+        "upper limit for recirculation loop temperature control"
     )
 
     # Enum field
@@ -1181,8 +1043,8 @@ class MqttCommand(NavienBaseModel):
     protocol_version: int = 2
 
 
-class EnergyUsageTotal(NavienBaseModel):
-    """Total energy usage data."""
+class EnergyUsageBase(NavienBaseModel):
+    """Base energy usage fields common to daily and total responses."""
 
     heat_pump_usage: int = Field(default=0, alias="hpUsage")
     heat_element_usage: int = Field(default=0, alias="heUsage")
@@ -1191,44 +1053,37 @@ class EnergyUsageTotal(NavienBaseModel):
 
     @property
     def total_usage(self) -> int:
-        """Total energy usage (heat pump + heat element)."""
         return self.heat_pump_usage + self.heat_element_usage
 
+
+class EnergyUsageTotal(EnergyUsageBase):
+    """Total energy usage data."""
+
     @property
     def heat_pump_percentage(self) -> float:
-        if self.total_usage == 0:
-            return 0.0
-        return (self.heat_pump_usage / self.total_usage) * 100.0
+        return (
+            (self.heat_pump_usage / self.total_usage * 100.0)
+            if self.total_usage > 0
+            else 0.0
+        )
 
     @property
     def heat_element_percentage(self) -> float:
-        if self.total_usage == 0:
-            return 0.0
-        return (self.heat_element_usage / self.total_usage) * 100.0
+        return (
+            (self.heat_element_usage / self.total_usage * 100.0)
+            if self.total_usage > 0
+            else 0.0
+        )
 
     @property
     def total_time(self) -> int:
-        """Total operating time (heat pump + heat element)."""
         return self.heat_pump_time + self.heat_element_time
 
 
-class EnergyUsageDay(NavienBaseModel):
-    """Daily energy usage data.
+class EnergyUsageDay(EnergyUsageBase):
+    """Daily energy usage data."""
 
-    Note: The API returns a fixed-length array (30 elements) for each month,
-    with unused days having all zeros. The day number is implicit from the
-    array index (0-based).
-    """
-
-    heat_pump_usage: int = Field(alias="hpUsage")
-    heat_element_usage: int = Field(alias="heUsage")
-    heat_pump_time: int = Field(alias="hpTime")
-    heat_element_time: int = Field(alias="heTime")
-
-    @property
-    def total_usage(self) -> int:
-        """Total energy usage (heat pump + heat element)."""
-        return self.heat_pump_usage + self.heat_element_usage
+    pass
 
 
 class MonthlyEnergyData(NavienBaseModel):
