@@ -9,10 +9,13 @@ and status up-to-date. Features include:
 - Per-device, per-type task management
 """
 
+from __future__ import annotations
+
 import asyncio
 import contextlib
 import logging
-from typing import Any, Callable, Optional
+from collections.abc import Callable
+from typing import Any
 
 from awscrt.exceptions import AwsCrtError
 
@@ -237,7 +240,7 @@ class MqttPeriodicRequestManager:
     async def stop_periodic_requests(
         self,
         device: Device,
-        request_type: Optional[PeriodicRequestType] = None,
+        request_type: PeriodicRequestType | None = None,
     ) -> None:
         """
         Stop sending periodic requests for a device.
@@ -288,9 +291,7 @@ class MqttPeriodicRequestManager:
                 + (f" (type={request_type.value})" if request_type else "")
             )
 
-    async def stop_all_periodic_tasks(
-        self, reason: Optional[str] = None
-    ) -> None:
+    async def stop_all_periodic_tasks(self, reason: str | None = None) -> None:
         """
         Stop all periodic request tasks.
 
